@@ -8,7 +8,6 @@ from scrapy.utils.trackref import object_ref
 from scrapy.utils.python import to_bytes
 from scrapy.http import HtmlResponse, XmlResponse
 from scrapy.utils.decorators import deprecated
-from scrapy.exceptions import ScrapyDeprecationWarning
 
 
 __all__ = ['Selector', 'SelectorList']
@@ -31,17 +30,6 @@ class SelectorList(_ParselSelector.selectorlist_cls, object_ref):
     The :class:`SelectorList` class is a subclass of the builtin ``list``
     class, which provides a few additional methods.
     """
-    @deprecated(use_instead='.extract()')
-    def extract_unquoted(self):
-        return [x.extract_unquoted() for x in self]
-
-    @deprecated(use_instead='.xpath()')
-    def x(self, xpath):
-        return self.select(xpath)
-
-    @deprecated(use_instead='.xpath()')
-    def select(self, xpath):
-        return self.xpath(xpath)
 
 
 class Selector(_ParselSelector, object_ref):
@@ -78,21 +66,13 @@ class Selector(_ParselSelector, object_ref):
     __slots__ = ['response']
     selectorlist_cls = SelectorList
 
-    def __init__(self, response=None, text=None, type=None, root=None, _root=None, **kwargs):
+    def __init__(self, response=None, text=None, type=None, root=None, **kwargs):
         if not(response is None or text is None):
            raise ValueError('%s.__init__() received both response and text'
                             % self.__class__.__name__)
 
         st = _st(response, type or self._default_type)
 
-        if _root is not None:
-            warnings.warn("Argument `_root` is deprecated, use `root` instead",
-                          ScrapyDeprecationWarning, stacklevel=2)
-            if root is None:
-                root = _root
-            else:
-                warnings.warn("Ignoring deprecated `_root` argument, using provided `root`")
-
         if text is not None:
             response = _response_from_text(text, st)
 
@@ -102,18 +82,3 @@ class Selector(_ParselSelector, object_ref):
 
         self.response = response
         super(Selector, self).__init__(text=text, type=st, root=root, **kwargs)
-
-    # Deprecated api
-    @property
-    def _root(self):
-        warnings.warn("Attribute `_root` is deprecated, use `root` instead",
-                      ScrapyDeprecationWarning, stacklevel=2)
-        return self.root
-
-    @deprecated(use_instead='.xpath()')
-    def select(self, xpath):
-        return self.xpath(xpath)
-
-    @deprecated(use_instead='.extract()')
-    def extract_unquoted(self):
-        return self.extract()
